permission.decorators package
=============================

Submodules
----------

permission.decorators.classbase module
--------------------------------------

.. automodule:: permission.decorators.classbase
    :members:
    :undoc-members:
    :show-inheritance:

permission.decorators.functionbase module
-----------------------------------------

.. automodule:: permission.decorators.functionbase
    :members:
    :undoc-members:
    :show-inheritance:

permission.decorators.methodbase module
---------------------------------------

.. automodule:: permission.decorators.methodbase
    :members:
    :undoc-members:
    :show-inheritance:

permission.decorators.permission_required module
------------------------------------------------

.. automodule:: permission.decorators.permission_required
    :members:
    :undoc-members:
    :show-inheritance:

permission.decorators.utils module
----------------------------------

.. automodule:: permission.decorators.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: permission.decorators
    :members:
    :undoc-members:
    :show-inheritance:
